Enum polkadot_node_subsystem_util::Error [−][src]
pub enum Error {
Oneshot(Canceled),
Mpsc(SendError),
Subsystem(SubsystemError),
RuntimeApi(RuntimeApiError),
Infallible(Infallible),
SenderConversion(String),
NotAValidator,
AlreadyForwarding,
}Expand description
Utility errors
Variants
Oneshot(Canceled)Attempted to send or receive on a oneshot channel which had been canceled
Tuple Fields of Oneshot
0: CanceledMpsc(SendError)Attempted to send on a MPSC channel which has been canceled
Tuple Fields of Mpsc
0: SendErrorSubsystem(SubsystemError)A subsystem error
Tuple Fields of Subsystem
RuntimeApi(RuntimeApiError)An error in the Runtime API.
Tuple Fields of RuntimeApi
Infallible(Infallible)The type system wants this even though it doesn’t make sense
Tuple Fields of Infallible
0: InfallibleSenderConversion(String)Attempted to convert from an AllMessages to a FromJob, and failed.
Tuple Fields of SenderConversion
0: StringThe local node is not a validator.
Already forwarding errors to another sender