Function polkadot_node_subsystem_util::gen_ratio [−][src]
pub fn gen_ratio(a: usize, b: usize) -> boolExpand description
Returns a bool with a probability of a / b of being true.
pub fn gen_ratio(a: usize, b: usize) -> boolReturns a bool with a probability of a / b of being true.