Function polkadot_node_subsystem_util::signing_key_and_index [−][src]
pub async fn signing_key_and_index(
validators: &[ValidatorId],
keystore: &SyncCryptoStorePtr
) -> Option<(ValidatorId, ValidatorIndex)>Expand description
From the given set of validators, find the first key we can sign with, if any, and return it along with the validator index.